@@ -19,9 +19,9 @@ class SmmsImg():
             self.qclient = QcloudClient(clientInfo[Config.QCLOUD_INFO_SECRET_ID], clientInfo[Config.QCLOUD_INFO_SECRET_KEY],
                                         clientInfo[Config.QCLOUD_INFO_REGION], clientInfo[Config.QCLOUD_INFO_BUCKET])
         try:
-            useUrlEncode = self.sysConfig.getConfigParam(Config.PARAM_USE_URL_ENCODE)
+            urlEncodeMode = self.sysConfig.getConfigParam(Config.PARAM_URL_ENCODE_MODE)
             url = self.qclient.upload(
-                path, clientInfo[Config.QCLOUD_INFO_DES_DIR], useUrlEncode)
+                path, clientInfo[Config.QCLOUD_INFO_DES_DIR], urlEncodeMode)
         except qcloud_cos.cos_exception.CosServiceError as e:
             self.sysConfig.writeErrorLog(str(e))
             return False
